@@ -5,7 +5,6 @@ from imbi.endpoints import base
 
 
 class RequestHandler(base.AuthenticatedRequestHandler):
-
     async def post(self, index: str):
         self.logger.debug('Request body: %r', self.get_request_body())
         try:
@@ -13,6 +12,6 @@ class RequestHandler(base.AuthenticatedRequestHandler):
                 index=index, body=self.get_request_body())
         except opensearchpy.RequestError as err:
             if err.status_code == 400:
-                raise errors.BadRequest(
-                    'OpenSearch request error', detail=err.info)
+                raise errors.BadRequest('OpenSearch request error',
+                                        detail=err.info)
         self.send_response(result)
