@@ -16,7 +16,8 @@ class CollectionRequestHandler(project.RequestHandlerMixin,
     NAME = 'project-fact-types'
     ID_KEY = 'project_id'
 
-    COLLECTION_SQL = re.sub(r'\s+', ' ', """\
+    COLLECTION_SQL = re.sub(
+        r'\s+', ' ', """\
         WITH project_type_id AS (SELECT project_type_id AS id
                                    FROM v1.projects
                                   WHERE id = %(project_id)s)
@@ -52,7 +53,8 @@ class CollectionRequestHandler(project.RequestHandlerMixin,
          WHERE (SELECT id FROM project_type_id) = ANY(a.project_type_ids)
         ORDER BY a.name""")
 
-    POST_SQL = re.sub(r'\s+', ' ', """\
+    POST_SQL = re.sub(
+        r'\s+', ' ', """\
         INSERT INTO v1.project_facts
                     (project_id, fact_type_id, recorded_at, recorded_by, value)
              VALUES (%(project_id)s, %(fact_type_id)s, CURRENT_TIMESTAMP,
@@ -63,9 +65,9 @@ class CollectionRequestHandler(project.RequestHandlerMixin,
                         value = %(value)s""")
 
     async def get(self, *args, **kwargs):
-        result = await self.postgres_execute(
-            self.COLLECTION_SQL, self._get_query_kwargs(kwargs),
-            'get-{}'.format(self.NAME))
+        result = await self.postgres_execute(self.COLLECTION_SQL,
+                                             self._get_query_kwargs(kwargs),
+                                             'get-{}'.format(self.NAME))
         self.send_response(common.coerce_project_fact_values(result.rows))
 
     async def post(self, *args, **kwargs):
@@ -75,8 +77,8 @@ class CollectionRequestHandler(project.RequestHandlerMixin,
                 'project_id': kwargs['project_id'],
                 'username': self._current_user.username
             })
-            await self.postgres_execute(
-                self.POST_SQL, fact, 'post-{}'.format(self.NAME))
+            await self.postgres_execute(self.POST_SQL, fact,
+                                        'post-{}'.format(self.NAME))
         await self.index_document(kwargs['project_id'])
         self.set_status(204)
 
@@ -109,8 +111,7 @@ class CollectionRequestHandler(project.RequestHandlerMixin,
         except ValueError as error:
             raise errors.BadRequest('invalid fact value: %s', error)
 
-    def on_postgres_error(self,
-                          metric_name: str,
+    def on_postgres_error(self, metric_name: str,
                           exc: Exception) -> typing.Optional[Exception]:
         """Invoked when an error occurs when executing a query
 
