@@ -10,7 +10,8 @@ class _LinkRequestMixin:
     FIELDS = ['project_id', 'link_type_id', 'url']
     TTL = 300
 
-    GET_SQL = re.sub(r'\s+', ' ', """\
+    GET_SQL = re.sub(
+        r'\s+', ' ', """\
         SELECT a.project_id,
                a.link_type_id,
                a.created_at,
@@ -33,7 +34,8 @@ class CollectionRequestHandler(projects.ProjectAttributeCollectionMixin,
 
     NAME = 'project-links'
 
-    COLLECTION_SQL = re.sub(r'\s+', ' ', """\
+    COLLECTION_SQL = re.sub(
+        r'\s+', ' ', """\
         SELECT a.project_id,
                a.link_type_id,
                a.created_at,
@@ -49,7 +51,8 @@ class CollectionRequestHandler(projects.ProjectAttributeCollectionMixin,
          WHERE a.project_id = %(project_id)s
          ORDER BY b.link_type""")
 
-    POST_SQL = re.sub(r'\s+', ' ', """\
+    POST_SQL = re.sub(
+        r'\s+', ' ', """\
         INSERT INTO v1.project_links
                     (project_id, link_type_id, created_by, url)
              VALUES (%(project_id)s, %(link_type_id)s, %(username)s, %(url)s)
@@ -61,12 +64,14 @@ class RecordRequestHandler(projects.ProjectAttributeCRUDMixin,
 
     NAME = 'project-link'
 
-    DELETE_SQL = re.sub(r'\s+', ' ', """\
+    DELETE_SQL = re.sub(
+        r'\s+', ' ', """\
         DELETE FROM v1.project_links
               WHERE project_id = %(project_id)s
                 AND link_type_id = %(link_type_id)s""")
 
-    PATCH_SQL = re.sub(r'\s+', ' ', """\
+    PATCH_SQL = re.sub(
+        r'\s+', ' ', """\
         UPDATE v1.project_links
            SET url=%(url)s,
                last_modified_at=CURRENT_TIMESTAMP,
