@@ -9,13 +9,15 @@ from imbi.opensearch import project
 class _RequestHandlerMixin:
     ITEM_NAME = 'project'
     ID_KEY = ['id']
-    FIELDS = ['id', 'namespace_id', 'project_type_id', 'name', 'slug',
-              'description', 'environments', 'archived', 'gitlab_project_id',
-              'sentry_project_slug', 'sonarqube_project_key',
-              'pagerduty_service_id']
+    FIELDS = [
+        'id', 'namespace_id', 'project_type_id', 'name', 'slug', 'description',
+        'environments', 'archived', 'gitlab_project_id', 'sentry_project_slug',
+        'sonarqube_project_key', 'pagerduty_service_id'
+    ]
     TTL = 300
 
-    GET_SQL = re.sub(r'\s+', ' ', """\
+    GET_SQL = re.sub(
+        r'\s+', ' ', """\
         SELECT a.id,
                a.created_at,
                a.created_by,
@@ -41,14 +43,12 @@ class _RequestHandlerMixin:
 
 
 class ProjectAttributeCollectionMixin(project.RequestHandlerMixin):
-
     async def post(self, *_args, **kwargs):
         result = await self._post(kwargs)
         await self.index_document(result['project_id'])
 
 
 class ProjectAttributeCRUDMixin(project.RequestHandlerMixin):
-
     async def delete(self, *args, **kwargs):
         await super().delete(*args, **kwargs)
         await self.index_document(kwargs['project_id'])
@@ -63,7 +63,8 @@ class CollectionRequestHandler(project.RequestHandlerMixin,
                                base.CollectionRequestHandler):
     NAME = 'projects'
     IS_COLLECTION = True
-    COLLECTION_SQL = re.sub(r'\s+', ' ', """\
+    COLLECTION_SQL = re.sub(
+        r'\s+', ' ', """\
         SELECT a.id,
                a.created_at,
                a.created_by,
@@ -91,7 +92,8 @@ class CollectionRequestHandler(project.RequestHandlerMixin,
           JOIN v1.project_types AS c ON c.id = a.project_type_id
           {{WHERE}} {{ORDER_BY}} LIMIT %(limit)s OFFSET %(offset)s""")
 
-    COUNT_SQL = re.sub(r'\s+', ' ', """\
+    COUNT_SQL = re.sub(
+        r'\s+', ' ', """\
         SELECT count(a.*) AS records
           FROM v1.projects AS a
           JOIN v1.namespaces AS b ON b.id = a.namespace_id
@@ -102,8 +104,8 @@ class CollectionRequestHandler(project.RequestHandlerMixin,
         'name': 'to_tsvector(lower(a.name)) @@ websearch_to_tsquery(%(name)s)',
         'namespace_id': 'b.id = %(namespace_id)s',
         'project_type_id': 'c.id = %(project_type_id)s',
-        'sonarqube_project_key':
-            'a.sonarqube_project_key = %(sonarqube_project_key)s',
+        'sonarqube_project_key': ('a.sonarqube_project_key = '
+                                  '%(sonarqube_project_key)s'),
     }
 
     SORT_MAP = {
@@ -117,7 +119,8 @@ class CollectionRequestHandler(project.RequestHandlerMixin,
         r'(?:(?P<column>name|namespace|project_score|project_type) '
         r'(?P<direction>asc|desc))')
 
-    POST_SQL = re.sub(r'\s+', ' ', """\
+    POST_SQL = re.sub(
+        r'\s+', ' ', """\
         INSERT INTO v1.projects
                     (namespace_id, project_type_id, created_by,  "name", slug,
                      description, environments)
@@ -152,27 +155,29 @@ class CollectionRequestHandler(project.RequestHandlerMixin,
             order_sql = ' ORDER BY {}'.format(', '.join(order_by_chunks))
         sql = sql.replace('{{ORDER_BY}}', order_sql)
 
-        count = await self.postgres_execute(
-            count_sql, kwargs, metric_name='count-{}'.format(self.NAME))
-        result = await self.postgres_execute(
-            sql, kwargs, metric_name='get-{}'.format(self.NAME))
-        self.send_response({
-            'rows': count.row['records'],
-            'data': result.rows})
+        count = await self.postgres_execute(count_sql,
+                                            kwargs,
+                                            metric_name='count-{}'.format(
+                                                self.NAME))
+        result = await self.postgres_execute(sql,
+                                             kwargs,
+                                             metric_name='get-{}'.format(
+                                                 self.NAME))
+        self.send_response({'rows': count.row['records'], 'data': result.rows})
 
     async def post(self, *_args, **kwargs):
         result = await self._post(kwargs)
         await self.index_document(result['id'])
 
 
-class RecordRequestHandler(project.RequestHandlerMixin,
-                           _RequestHandlerMixin,
+class RecordRequestHandler(project.RequestHandlerMixin, _RequestHandlerMixin,
                            base.CRUDRequestHandler):
     NAME = 'project'
 
     DELETE_SQL = 'DELETE FROM v1.projects WHERE id=%(id)s'
 
-    GET_FULL_SQL = re.sub(r'\s+', ' ', """\
+    GET_FULL_SQL = re.sub(
+        r'\s+', ' ', """\
         SELECT a.id,
                a.created_at,
                a.created_by,
@@ -201,7 +206,8 @@ class RecordRequestHandler(project.RequestHandlerMixin,
           JOIN v1.project_types AS c ON c.id = a.project_type_id
          WHERE a.id=%(id)s""")
 
-    GET_FACTS_SQL = re.sub(r'\s+', ' ', """\
+    GET_FACTS_SQL = re.sub(
+        r'\s+', ' ', """\
         WITH project_type_id AS (SELECT project_type_id AS id
                                    FROM v1.projects
                                   WHERE id = %(id)s)
@@ -253,7 +259,8 @@ class RecordRequestHandler(project.RequestHandlerMixin,
          WHERE (SELECT id FROM project_type_id) = ANY(a.project_type_ids)
         ORDER BY a.name""")
 
-    GET_LINKS_SQL = re.sub(r'\s+', ' ', """\
+    GET_LINKS_SQL = re.sub(
+        r'\s+', ' ', """\
         SELECT a.link_type_id,
                b.link_type AS title,
                b.icon_class AS icon,
@@ -263,13 +270,15 @@ class RecordRequestHandler(project.RequestHandlerMixin,
          WHERE a.project_id=%(id)s
          ORDER BY b.link_type""")
 
-    GET_URLS_SQL = re.sub(r'\s+', ' ', """\
+    GET_URLS_SQL = re.sub(
+        r'\s+', ' ', """\
         SELECT environment, url
           FROM v1.project_urls
          WHERE project_id=%(id)s
          ORDER BY environment""")
 
-    PATCH_SQL = re.sub(r'\s+', ' ', """\
+    PATCH_SQL = re.sub(
+        r'\s+', ' ', """\
         UPDATE v1.projects
            SET namespace_id=%(namespace_id)s,
                project_type_id=%(project_type_id)s,
@@ -294,14 +303,14 @@ class RecordRequestHandler(project.RequestHandlerMixin,
         if self.get_argument('full', 'false') == 'true':
             query_args = self._get_query_kwargs(kwargs)
             project, facts, links, urls = await asyncio.gather(
-                self.postgres_execute(
-                    self.GET_FULL_SQL, query_args, 'get-{}'.format(self.NAME)),
-                self.postgres_execute(
-                    self.GET_FACTS_SQL, query_args, 'get-project-facts'),
-                self.postgres_execute(
-                    self.GET_LINKS_SQL, query_args, 'get-project-links'),
-                self.postgres_execute(
-                    self.GET_URLS_SQL, query_args, 'get-project-urls'))
+                self.postgres_execute(self.GET_FULL_SQL, query_args,
+                                      'get-{}'.format(self.NAME)),
+                self.postgres_execute(self.GET_FACTS_SQL, query_args,
+                                      'get-project-facts'),
+                self.postgres_execute(self.GET_LINKS_SQL, query_args,
+                                      'get-project-links'),
+                self.postgres_execute(self.GET_URLS_SQL, query_args,
+                                      'get-project-urls'))
 
             if not project.row_count or not project.row:
                 raise errors.ItemNotFound()
@@ -310,7 +319,8 @@ class RecordRequestHandler(project.RequestHandlerMixin,
             output.update({
                 'facts': facts.rows,
                 'links': links.rows,
-                'urls': {row['environment']: row['url'] for row in urls.rows}
+                'urls': {row['environment']: row['url']
+                         for row in urls.rows}
             })
             self.send_response(output)
         else:
@@ -323,7 +333,6 @@ class RecordRequestHandler(project.RequestHandlerMixin,
 
 class SearchRequestHandler(project.RequestHandlerMixin,
                            base.AuthenticatedRequestHandler):
-
     async def get(self):
         result = await self.search_index.search(self.get_query_argument('s'))
         self.send_response(result)
@@ -331,7 +340,8 @@ class SearchRequestHandler(project.RequestHandlerMixin,
 
 class SearchIndexRequestHandler(project.RequestHandlerMixin,
                                 base.ValidatingRequestHandler):
-    SQL = re.sub(r'\s+', ' ', """\
+    SQL = re.sub(
+        r'\s+', ' ', """\
         SELECT id
           FROM v1.projects
          ORDER BY id""")
@@ -344,4 +354,5 @@ class SearchIndexRequestHandler(project.RequestHandlerMixin,
 
         self.send_response({
             'status': 'ok',
-            'message': f'Queued {len(result)} projects for indexing'})
+            'message': f'Queued {len(result)} projects for indexing'
+        })
